==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/osc/OSC_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>OSC Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universen konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Eingangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Ausgangsadresse</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Ausgangsport</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="80"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="86"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="85"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Dieses Plugin bietet Eingabunterstützung für Geräte mit dem OSC-Protokoll.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="136"/>
        <location filename="oscplugin.cpp" line="270"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="139"/>
        <location filename="oscplugin.cpp" line="273"/>
        <source>Status: Open</source>
        <translation>Status: Geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="141"/>
        <source>Packets sent: </source>
        <translation>Pakete gesendet: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="275"/>
        <source>Packets received: </source>
        <translation>Pakete empfangen: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="132"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="266"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/osc/OSC_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>OSC Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universen konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Eingangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Ausgangsadresse</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Ausgangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="88"/>
        <source>Channel number calculator</source>
        <translation>Kanalnummer-Rechner</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="96"/>
        <source>OSC path</source>
        <translation>OSC-Pfad</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="106"/>
        <source>Channel number</source>
        <translation>Kanal-Nummer</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="83"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="89"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="91"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Dieses Plugin bietet Eingabunterstützung für Geräte mit dem OSC-Protokoll.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="142"/>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="145"/>
        <location filename="oscplugin.cpp" line="279"/>
        <source>Status: Open</source>
        <translation>Status: Geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <source>Packets sent: </source>
        <translation>Pakete gesendet: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="281"/>
        <source>Packets received: </source>
        <translation>Pakete empfangen: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="138"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="272"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
</context>
</TS>
